==> antiright-2.99.2.tar.bz2: antiright/gtkshell/main.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_setup_containers()
{
 gsh_hbox = gtk_hbox_new(FALSE, 2);
 gtk_container_add(GTK_CONTAINER(gsh_window), gsh_hbox);
 gtk_widget_show(gsh_hbox);
 gsh_vbox = gtk_vbox_new(FALSE, 2);
 gtk_container_add(GTK_CONTAINER(gsh_hbox), gsh_vbox);
 gtk_widget_show(gsh_vbox);
}

int
main(int argc, char **argv)
{
 	gtk_init(&argc, &argv);

 	gsh_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	g_signal_connect (gsh_window, "delete-event",
		G_CALLBACK (gtk_main_quit), NULL);
  	g_signal_connect (gsh_window, "destroy",
		G_CALLBACK (gtk_main_quit), NULL); 
	gsh_setup_containers();
 	gsh_handle_arguments(argc, argv);
 	gtk_widget_show(gsh_window);
	
 	gtk_main();

	return (0);
}

==> antiright-2.99.3.tar.bz2: antiright/gtkshell/main.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_setup_containers()
{
 gsh_hbox = gtk_hbox_new(FALSE, 2);
 gtk_container_add(GTK_CONTAINER(gsh_window), gsh_hbox);
 gtk_widget_show(gsh_hbox);
 gsh_vbox = gtk_vbox_new(FALSE, 2);
 gtk_container_add(GTK_CONTAINER(gsh_hbox), gsh_vbox);
 gtk_widget_show(gsh_vbox);
}

int
main(int argc, char **argv)
{
 	gtk_init(&argc, &argv);

 	gsh_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	g_signal_connect (gsh_window, "delete-event",
		G_CALLBACK (gtk_main_quit), NULL);
  	g_signal_connect (gsh_window, "destroy",
		G_CALLBACK (gtk_main_quit), NULL); 
	gsh_setup_containers();
 	gsh_parse_arguments(argc, argv);
 	gtk_widget_show(gsh_window);
	
 	gtk_main();

	return (0);
}
